Improve this Doc View Source

## Methods

- ###

  `errorOnUnhandledRejections([value]);`

  Retrieves or overrides whether to generate an error when a rejected promise is not handled. This feature is enabled by default.

  #### Parameters

  Param | Type | Details
  --- | --- | ---
  value (optional) | boolean | Whether to generate an error when a rejected promise is not handled.

  #### Returns

  booleanng.$qProvider | Current value when called without a new value or self for chaining otherwise.